#
# spec file for package votca-xtp
#
# Copyright (c) 2016-2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2018-2019 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           votca-xtp
Version:        1.5
%define         uversion %{version}
%define         sover 5
Release:        1.1
Summary:        VOTCA excitation and charge properties module
License:        Apache-2.0
Group:          Productivity/Scientific/Chemistry
Url:            http://www.votca.org
Source0:        https://github.com/votca/xtp/archive/v%{uversion}.tar.gz#/%{name}-%{uversion}.tar.gz
Source1:        https://github.com/votca/xtp/releases/download/v%{uversion}/votca-xtp-manual-%{uversion}.pdf

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  gcc-c++
BuildRequires:  pkg-config
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_program_options-devel >= 1.48.0
BuildRequires:  libboost_serialization-devel >= 1.48.0
BuildRequires:  libboost_filesystem-devel >= 1.48.0
BuildRequires:  libboost_system-devel >= 1.48.0
BuildRequires:  libboost_timer-devel >= 1.48.0
BuildRequires:  libboost_test-devel
%else
BuildRequires:  boost-devel >= 1.39.0
%endif
BuildRequires:  cmake >= 2.8.4
BuildRequires:  fdupes
BuildRequires:  votca-csg-devel = %{version}
BuildRequires:  libxc-devel
BuildRequires:  libceres-devel
BuildRequires:  hdf5-devel
 #for hdf5
BuildRequires:  zlib-devel

#exact same version is needed
Requires:       %{name}-common = %{version}
Requires:       libvotca_xtp%sover = %{version}

%description
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the excitation and charge properties module for VOTCA.

%package -n libvotca_xtp%sover
Summary:        VOTCA excitation and charge properties module
Group:          System/Libraries

%description -n libvotca_xtp%sover
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the libraries for the excitation and charge
properties module for VOTCA.

%package devel
Summary:        Development headers and libraries for VOTCA XTP
Group:          Development/Libraries/C and C++
Requires:       libvotca_xtp%sover = %{version}
Requires:       %{name} = %{version}
Requires:       votca-csg-devel = %{version}

%description devel
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the development headers and libraries for the
excitation and charge properties module engine for VOTCA.

%package common
Summary:        Architecture-independent data files for VOTCA XTP
Group:          Productivity/Scientific/Chemistry
BuildArch:      noarch

%description common
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the architecture-independent data files for VOTCA XTP.

%package doc
Summary:        Architecture independent doc files for VOTCA XTP
Group:          Documentation/Other
BuildArch:      noarch

%description doc
Versatile Object-oriented Toolkit for Coarse-graining Applications (VOTCA) is
a package to reduce the amount of routine work when doing systematic
coarse-graining of various systems. The core is written in C++.

This package contains the architecture-independent documentation files for VOTCA XTP.

%prep
%setup -n xtp-%{uversion} -q

FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/libxtp/version.cc

# long.bst has non-profit purposes license, but it is not used for build
rm -v manual/long.bst

%build
%{cmake} -DCMAKE_SKIP_RPATH:BOOL=OFF -DLIB=%{_lib} -DBUILD_MANPAGES=ON -DENABLE_TESTING=ON
make #%{?_smp_mflags}

%install
make -C build install DESTDIR=%{buildroot}
sed -i -e '1s@env python@python2@'  %{buildroot}/%{_bindir}/xtp_*

%define pkgdocdir %{_docdir}/%{name}
mkdir -p %{buildroot}%{pkgdocdir}
cp %{S:1} %{buildroot}%{pkgdocdir}

%fdupes %{buildroot}%{_prefix}

%check
make -C build test CTEST_OUTPUT_ON_FAILURE=1

%post -n libvotca_xtp%sover -p /sbin/ldconfig
%postun -n libvotca_xtp%sover -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_bindir}/xtp_*
%{_mandir}/man1/xtp_*

%files doc
%defattr(-,root,root,-)
%doc CHANGELOG.md NOTICE README.md
%license LICENSE.md
%{pkgdocdir}

%files common
%license LICENSE.md
%defattr(-,root,root,-)
%{_datadir}/votca

%files -n libvotca_xtp%sover
%defattr(-,root,root,-)
%{_libdir}/libvotca_xtp.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/votca/xtp/
%{_libdir}/libvotca_xtp.so
%{_libdir}/pkgconfig/libvotca_xtp.pc

%changelog
* Thu Jan 31 2019 Christoph Junghans <junghans@votca.org>
- Upgrade to 1.5
  * fix parallel build of manual
  * fix usage on inkscape on arm arch
  * clean up namespace in header
  * optimized GW-BSE code and integral engine
  * added closed shell DFT code which supports hybrid functionals
  * removed ctp dependency
  * atm no support for site energy calculation
  * CHELPG fit for ground and excited states
  * merged igwbse and idft into one calculator
  * added unit and integration test
  * improved geometry optimiser
  * replaced ublas with Eigen3
  * replaced boost serialisation with hdf5 files
  * Details: https://github.com/votca/xtp/blob/stable/CHANGELOG.md
- Drop 55.patch, merged upstream
* Thu Oct 12 2017 junghans@votca.org
- Add 55.patch to fix compile with gcc-7
* Wed Oct 11 2017 junghans@votca.org
- split boost-devel into libboost-* (bug #1062801)
* Sun Sep  3 2017 junghans@votca.org
- Upgrade to 1.4.1
  * fix pkg-config file
  * Details: https://github.com/votca/xtp/blob/master/CHANGELOG.md
* Sat Jan 21 2017 junghans@votca.org
- Implemeted suggestions from Request #437970
* Mon Oct 31 2016 jengelh@inai.de
- Update summaries and descriptions
* Sat Oct 29 2016 junghans@votca.org
- Upgrade to 1.4
  * dropped merged patch, for cmake underlinking and boost-1.62
  * fixed a bug in gwbse
  * Details: https://github.com/votca/xtp/blob/master/CHANGELOG.md
* Thu Oct 20 2016 junghans@votca.org
- Added patch from upstream to support boost-1.62
* Wed Sep 28 2016 junghans@votca.org
- Initial import of version 1.4_rc1
